@@ -1,5 +1,7 @@
-from .woqlclient import WOQLClient  # noqa
+from .client import Patch, Client  # noqa
 from .woqldataframe import woqlDataframe as WOQLDataFrame  # noqa
 from .woqlquery import WOQLQuery  # noqa
 from .woqlschema import *  # noqa
-from .woqlview import WOQLView  # noqa
+# Backwards compatibility
+WOQLClient = Client # noqa
+WOQLSchema = Schema # noqa
