@@ -1,11 +1,13 @@
 WOQL_JOIN_SPLIT_JSON = {
     "joinJson": {
         "@type": "Join",
-        "list": {"@type": "DataValue",
-                 "list": [
-                     {"@type": "DataValue", "variable": "A_obj"},
-                     {"@type": "DataValue", "variable": "B_obj"},
-                 ]},
+        "list": {
+            "@type": "DataValue",
+            "list": [
+                {"@type": "DataValue", "variable": "A_obj"},
+                {"@type": "DataValue", "variable": "B_obj"},
+            ],
+        },
         "separator": {
             "@type": "DataValue",
             "data": {"@type": "xsd:string", "@value": ", "},
